@@ -14,12 +14,13 @@ class CryptoCSV:
         self._log = Logging(name=CryptoCSV.__name__, level=Logging.DEBUG)
 
         self.df = None
+        self.csv = csv
 
         if csv:
             self.df = pd.read_csv(csv, delimiter=delimiter, **kwargs)
 
         if fake_csv:
-            self.df = self.csv_from_string(csv, delimiter=delimiter, **kwargs)
+            self.df = self.csv_from_string(fake_csv, delimiter=delimiter, **kwargs)
 
         if dataframe is not None:
             self.df = dataframe
